/**
 * @file
 * Client-side script to integrate private message with browser notifications.
 */

/*global Drupal, drupalSettings, io, Notification, window*/
/*jslint white:true, this, browser:true*/

(function (Drupal, drupalSettings, io, Notification, window) {

  "use strict";

  var initialized, browserNotificationSocket;

  function checkPermission() {

    if (window.hasOwnProperty("Notification")) {
      var permission = Notification.permission;

      if (permission === "granted") {
        return true;
      }

      if (permission !== "denied") {
        Notification.requestPermission().then(function () {
          return true;
        });
      }
    }
  }

  function showBrowserNotification(body, icon, title, link, duration) {

    if (checkPermission()) {

      // Default duration is 5 seconds.
      duration = duration || 5000;

      var options = {
        body: body,
        icon: icon
      };

      // Create the notification.
      var n = new Notification(title, options);

      // Set a click listener if a link was passed.
      if (link) {
        n.onclick = function () {
          window.open(link);
        };
      }

      // Set the notification to close after the duration.
      setTimeout(n.close.bind(n), duration);
    }
  }

  function notifyBrowserOfNewMessage(message) {

    showBrowserNotification(message.body, message.icon, message.title, message.link);
  }

  function init() {

    // Only initialize once.
    if (!initialized) {
      initialized = true;

      browserNotificationSocket = io(drupalSettings.privateMessageNodejs.nodejsUrl + "/pm_browser_notification");

      // Listen for a connection to the remote server.
      browserNotificationSocket.on("connect", function () {
         // Enter the room for this user.
         browserNotificationSocket.emit("user", drupalSettings.user.uid);
      });

      // Listen for an emission informing of a notification of a new message for
      // the current user.
      browserNotificationSocket.on("notify browser new message", function (message) {
        // Send a browser notification of the new message.
        notifyBrowserOfNewMessage(message);
      });
    }
  }

  Drupal.behaviors.privateMessageNodejsBrowserNotify = {
    attach: function () {
      init();
    }
  };

}(Drupal, drupalSettings, io, Notification, window));
