/**
 * @file
 * Client-side script integrating private message notification block and Nodejs.
 */

/*global jQuery, Drupal, drupalSettings, io*/
/*jslint white:true, this, browser:true*/

(function ($, Drupal, drupalSettings, io) {

  "use strict";

  var initialized, notificationSocket;

  function init() {

    // Only initialize once.
    if (!initialized) {
      initialized = true;

      notificationSocket = io(drupalSettings.privateMessageNodejs.nodejsUrl + "/pm_notifications");

      // Listen for a connection to the remote server.
      notificationSocket.on('connect', function () {
         // Enter the room for this user.
         notificationSocket.emit('user', drupalSettings.user.uid);
      });

      // Listen for an emission informing of thread update for a thread the user
      // belongs to.
      notificationSocket.on("update pm unread thread count", function () {
        // Fetch unread thread count from the server.
        Drupal.PrivateMessageNotificationBlock.getUnreadThreadCount();
      });

      Drupal.AjaxCommands.prototype.privateMessageNodejsTriggerUnreadThreadCountUpdateCommand = function (ajax, response) {

        // For jSlint compatibility.
        ajax = ajax;

        if (Drupal.PrivateMessageNotificationBlock) {
          $.each(response.uids, function (index) {
            notificationSocket.emit("update pm unread thread count", response.uids[index]);
          });
        }
      };
    }
  }

  Drupal.behaviors.privateMessageNodejsNotificationBlock = {
    attach: function () {
      init();
    }
  };

}(jQuery, Drupal, drupalSettings, io));
